#include <Adafruit_NeoPixel.h>

#define LED 1
#define BTN1 0
#define BTN2 2

int lastButton1State = LOW;
int lastButton2State = LOW;

int ledCount = 56;

// Parameter 1 = number of pixels in strip
// Parameter 2 = pin number (most are valid)
// Parameter 3 = pixel type flags, add together as needed:
//   NEO_KHZ800  800 KHz bitstream (most NeoPixel products w/WS2812 LEDs)
//   NEO_KHZ400  400 KHz (classic 'v1' (not v2) FLORA pixels, WS2811 drivers)
//   NEO_GRB     Pixels are wired for GRB bitstream (most NeoPixel products)
//   NEO_RGB     Pixels are wired for RGB bitstream (v1 FLORA pixels, not v2)
Adafruit_NeoPixel strip = Adafruit_NeoPixel(ledCount, LED, NEO_GRB + NEO_KHZ800);

uint32_t colors[5] = {strip.Color(255, 255, 0), // yellow
                     strip.Color(127, 0, 255), // purple
                     strip.Color(0, 255, 0), // green
                     strip.Color(255, 0, 0), // red
                     strip.Color(0, 0, 255)}; // blue
                     
int currentColor = 0;
int maxColor = 5;
int defaultBrightness = 50;

void setup() {     
  // initialize the pushbutton pin as an input:
  pinMode(BTN1, INPUT_PULLUP);
  pinMode(BTN2, INPUT_PULLUP);  
  
  strip.begin();
  
  for (int i = 0; i < ledCount; i++)
  {
    strip.setPixelColor(i, colors[currentColor]);
  }
  
  // Get brighter
  for (int i = 5; i < defaultBrightness; i += 2)
   {
     strip.setBrightness(i);
     strip.show(); 
     delay(50);
   }
}

void loop(){
  for (int i = 0; i < 2000; i++)
  {
    int button1State = digitalRead(BTN1);
    
    if (button1State != lastButton1State)
    {
       lastButton1State = button1State;
       
       if (button1State == LOW)
         changeColor();
    }
    
    int button2State = digitalRead(BTN2);
    
    if (button2State != lastButton2State)
    {
       lastButton2State = button2State;
       
       if (button2State == LOW)
         fireArrow();
    }
    
    delay(5);
  }
  pulse();
}

void pulse()
{
   // Get slightly dimmer
  for (int i = defaultBrightness; i > defaultBrightness / 2; i -= 5)
   {
     strip.setBrightness(i);
     strip.show(); 
     delay(50);
   }
   
   // Get brighter
  for (int i = defaultBrightness / 2; i < defaultBrightness; i += 5)
   {
     strip.setBrightness(i);
     strip.show(); 
     delay(50);
   }
}

void changeColor()
{
  currentColor++;
  if (currentColor == maxColor)
  {
    currentColor = 0;
  }
   
   int i1 = 2;
   int i2 = 27;
   int i3 = 28;
   int i4 = 55;
   
   // Loop through and change color
   for (int i = 0; i < 14; i++)
   {
     // Set colors
     strip.setPixelColor(i1, colors[currentColor]);
     strip.setPixelColor(i2, colors[currentColor]);
     strip.setPixelColor(i3, colors[currentColor]);
     strip.setPixelColor(i4, colors[currentColor]);
     
     // Update iterators
     if (i == 3)
       i1 = 1;
     else if (i == 4)
       i1 = 6;
     else if (i == 5)
       i1 = 0;
     else if (i == 6)
       i1 = 7;
     else
       i1++;
     
     i2--;
     i3++;
     i4--;
     
     // Update and wait a bit
     strip.show(); 
     delay(50);
   }
}

void fireArrow()
{
  // Get slightly dimmer
  for (int i = defaultBrightness; i > 20; i -= 5)
   {
     strip.setBrightness(i);
     strip.show(); 
     delay(20);
   }
  
  // Get brighter
  for (int i = 20; i < 250; i += 5)
   {
     strip.setBrightness(i);
     strip.show(); 
     delay(30);
   }
   
   // Stay bright a bit
   delay(800);
   
   // Get dimmer
   for (int i = 250; i > defaultBrightness; i -= 10)
   {
     strip.setBrightness(i);
     strip.show(); 
     delay(30);
   }
}
